<?php
/*
Plugin Name: WP Post to PDF
Plugin URI: http://www.vareen.co.cc
Description: Allow visitor to download post in PDF format. No addon or change required on server. Use TCPDF class to generate PDF. Click 'Settings' link to configure plugin.
Version: 1.3
Author: Neerav
Author URI: http://www.vareen.co.cc

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// Define certain terms which may be required throughout the plugin
define('WPPT0PDF_PATH', WP_PLUGIN_DIR . '/wp-post-to-pdf');
define('WPPT0PDF_URL', WP_PLUGIN_URL . '/wp-post-to-pdf');
define('WPPT0PDF_BASENAME', plugin_basename(__FILE__));

// Add Menu in Administration area for configuration page
add_action('admin_menu', 'wpptopdf_admin_actions');

// Admin actions
function wpptopdf_admin_actions() {
    // Add options page
    $tp_option_page = add_options_page('WP Post to PDF Options', 'WP Post to PDF', 'administrator', WPPT0PDF_BASENAME, 'wpptopdf_options');
    // Register settings for plugin
    add_action('admin_init', 'wpptopdf_options_init');
    // Add color picker script
    add_action("admin_print_scripts-$tp_option_page", 'wpptopdf_admin_scripts');
}

// Include file containing options page form
function wpptopdf_options() {
    include('wpptopdf_options.php');
}

// Register settings for plugin
function wpptopdf_options_init() {
    register_setting('wpptopdf_options', 'wpptopdf');
}

// Add script requried in admin options page
function wpptopdf_admin_scripts() {
    wp_enqueue_script('farbtastic', WPPT0PDF_URL . '/asset/farbtastic/farbtastic.js', 'jquery');
    echo '<link rel="stylesheet" href="' . WPPT0PDF_URL . '/asset/farbtastic/farbtastic.css" type="text/css" />' . "\n";
    echo '<link rel="stylesheet" href="' . WPPT0PDF_URL . '/asset/css/admin.css" type="text/css" />' . "\n";
}

// Add settings link on plugin list page
function wpptopdf_settings_link($links) {
    $settings_link = '<a href="options-general.php?page=' . WPPT0PDF_BASENAME . '">Settings</a>';
    array_unshift($links, $settings_link);
    return $links;
}

add_filter("plugin_action_links_" . WPPT0PDF_BASENAME, 'wpptopdf_settings_link');

add_action('wp', 'wpptopdf_generate_pdf');
function wpptopdf_generate_pdf() {
    $wpptopdfopts = get_option('wpptopdf');
    if ('pdf' == $_GET['format']) {

        if ($wpptopdfopts['nonPublic'] and !is_user_logged_in())
            return false;
        if ($wpptopdfopts['onSingle'] and !(is_single() or is_page()))
            return false;

        global $post;
        $exclude = explode(',', $wpptopdfopts['excludeThis']);
        if (in_array($post->ID, $exclude))
            return;
        $post->post_content = wpautop($post->post_content);


        require_once(WPPT0PDF_PATH . '/tcpdf/config/lang/eng.php');
        require_once(WPPT0PDF_PATH . '/tcpdf/tcpdf.php');
        // create new PDF document
        $pdf = new TCPDF(PDF_PAGE_ORIENTATION, PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);
        global $post;
        if ($wpptopdfopts['otherPlugin'])
            $post->post_content = apply_filters('the_content', $post->post_content);
        else
            $post->post_content = wpautop($post->post_content);
        // set document information
        $pdf->SetCreator('Wordpress Post to PDF plugin(http://www.vareen.co.cc) with ' . PDF_CREATOR);
        $pdf->SetAuthor(get_bloginfo('name'));
        $pdf->SetTitle($post->post_title);

        // Count width of logo for better presenatation
        $logodata = getimagesize(PDF_HEADER_LOGO);
        $logowidth = (int) ((14 * $logodata[0]) / $logodata[1]);

        //$pdf->SetSubject('TCPDF Tutorial');
        //$pdf->SetKeywords('TCPDF, PDF, example, test, guide');
        // set default header data
        $pdf->SetHeaderData(PDF_HEADER_LOGO, $logowidth, html_entity_decode(get_bloginfo('name')), html_entity_decode(get_bloginfo('description') . "\n" . get_bloginfo('siteurl')));
        // set header and footer fonts
        $pdf->setHeaderFont(Array($wpptopdfopts['headerFont'], '', $wpptopdfopts['headerFontSize']));
        $pdf->setFooterFont(Array($wpptopdfopts['footerFont'], '', $wpptopdfopts['footerFontSize']));
        // set default monospaced font
        $pdf->SetDefaultMonospacedFont(PDF_FONT_MONOSPACED);
        //set margins
        $pdf->SetMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP, PDF_MARGIN_RIGHT);
        $pdf->SetHeaderMargin(PDF_MARGIN_HEADER);
        $pdf->SetFooterMargin(PDF_MARGIN_FOOTER);
        //set auto page breaks
        $pdf->SetAutoPageBreak(TRUE, PDF_MARGIN_BOTTOM);
        //set image scale factor
        $pdf->setImageScale(PDF_IMAGE_SCALE_RATIO);
        //set some language-dependent strings
        $pdf->setLanguageArray($l);
        // ---------------------------------------------------------
        // set default font subsetting mode
        $pdf->setFontSubsetting(true);
        // Set font
        // dejavusans is a UTF-8 Unicode font, if you only need to
        // print standard ASCII chars, you can use core fonts like
        // helvetica or times to reduce file size.
        $pdf->SetFont($wpptopdfopts['contentFont'], '', $wpptopdfopts['contentFontSize'], '', true);
        // Add a page
        // This method has several options, check the source code documentation for more information.
        $pdf->AddPage();
        // Set some content to print
        $html = '<h1>' . html_entity_decode($post->post_title) . '</h1>';
        $html .= html_entity_decode($post->post_content);
        // Print text using writeHTMLCell()
        $pdf->writeHTMLCell($w = 0, $h = 0, $x = '', $y = '', $html, $border = 0, $ln = 1, $fill = 0, $reseth = true, $align = '', $autopadding = true);
        // ---------------------------------------------------------
        // Close and output PDF document
        // This method has several options, check the source code documentation for more information.
        $pdf->Output($post->post_name . '.pdf', 'FI');
    }
}

add_filter('the_content', 'wpptopdf_add_button');
function wpptopdf_add_button($content) {

    if ('pdf' == $_GET['format'])
        return;

    $wpptopdfopts = get_option('wpptopdf');
    // If manual is selected, let user decide where to add button
    if ('manual' == $wpptopdfopts['iconPosition'])
        return $content;
    // get all options
    $wpptopdfopts = get_option('wpptopdf');
    // get button html
    $button = wpptopdf_display_icon();

    // Set button after and before post
    if ('beforeandafter' == $wpptopdfopts['iconPosition'])
        $content = $button . $content . $button;
        // Set button after post
    elseif ('after' == $wpptopdfopts['iconPosition'])
        $content = $content . $button;
        // by default Set button before post
    else
        $content = $button . $content;
    return $content;
}

/**
 * Return button HTML is required condition satisfied
 * @return string
 */
function wpptopdf_display_icon() {
    // get all options
    $wpptopdfopts = get_option('wpptopdf');

    // return nothing if no permission
    if ($wpptopdfopts['nonPublic'] and !is_user_logged_in())
        return;

    if ($wpptopdfopts['onSingle'] and !(is_single() or is_page()))
        return;

    global $post;
    // return nothing if post in exclude list
    $exclude = explode(',', $wpptopdfopts['excludeThis']);
    if (in_array($post->ID, $exclude))
        return;

    // Change separator for those who do not have pretty URL enabled
    $qst = get_permalink($post->ID);
    $qst = parse_url($qst);
    if ($qst['query'])
        $qst = '&format=pdf';
    else
        $qst = '?format=pdf';

    return '<a class="wpptopdf" href="' . get_permalink($post->ID) . $qst . '" title="Download PDF"><img src="' . $wpptopdfopts['imageIcon'] . '" alt="Download PDF"/></a>';

}

register_activation_hook(WPPT0PDF_BASENAME, 'wpptopdf_on_activate');

function wpptopdf_on_activate() {
    if (!file_exists(WP_CONTENT_DIR . '/uploads/wp-post-to-pdf-logo.png'))
        copy(WPPT0PDF_PATH . '/asset/images/logo.png', WP_CONTENT_DIR . '/uploads/wp-post-to-pdf-logo.png');
}